==> mediaelement-3.1.3.tgz: package/src/js/languages/zh.js <==
'use strict';

/*!
 * This is a `i18n` language object.
 *
 * Chinese (Traditional)
 *
 * @author
 *   Jalios (Twitter: @Jalios)
 *   Sascha Greuel (Twitter: @SoftCreatR)
 *
 * @see core/i18n.js
 */
(function (exports) {
	if (exports.zh === undefined) {
		exports.zh = {
			"mejs.plural-form": 0,

			// renderers/flash.js
			// "mejs.install-flash": "You are using a browser that does not have Flash player enabled or installed. Please turn on your Flash player plugin or download the latest version from https://get.adobe.com/flashplayer/",

			// features/contextmenu.js
			"mejs.fullscreen-off": "關閉全屏",
			"mejs.fullscreen-on": "轉向全屏",
			"mejs.download-video": "下載視頻",

			// features/fullscreen.js
			"mejs.fullscreen": "全屏",

			// features/jumpforward.js
			//"mejs.time-jump-forward": "Jump forward %1 second(s)",

			// features/loop.js
			//"mejs.loop": "Toggle Loop",

			// features/playpause.js
			"mejs.play": "播放",
			"mejs.pause": "暫停",

			// features/postroll.js
			"mejs.close": "關閉",

			// features/progress.js
			"mejs.time-slider": "時間滑動棒",
			"mejs.time-help-text": "使用左/右箭頭快進1秒，上/下箭頭快進10秒。",

			// features/skipback.js
			"mejs.time-skip-back": "跳躍式迴繞%1秒",

			// features/tracks.js
			"mejs.captions-subtitles": "字幕/標題",
			// "mejs.captions-chapters": "Chapters",
			"mejs.none": "沒有",

			// features/volume.js
			"mejs.volume-help-text": "使用上/下箭頭提高或降低音量。",
			"mejs.unmute": "取消靜音",
			"mejs.mute": "靜音",
			"mejs.volume-slider": "音量控制鍵",

			// core/player.js
			"mejs.video-player": "視頻播放器",
			"mejs.audio-player": "音頻播放器"

			// features/ads.js
			//"mejs.ad-skip": "Skip ad",
			//"mejs.ad-skip-info": "Skip in %1 second(s)",

			// features/sourcechooser.js
			//"mejs.source-chooser": "Source Chooser",

			// features/stop.js
			//"mejs.stop": "Stop",

			//features/speed.js
			//"mejs.speed-rate" : "Speed Rate",

			//features/progress.js
			//"mejs.live-broadcast" : "Live Broadcast",

			// features/tracks.js
			// "mejs.afrikaans": "Afrikaans",
			// "mejs.albanian": "Albanian",
			// "mejs.arabic": "Arabic",
			// "mejs.belarusian": "Belarusian",
			// "mejs.bulgarian": "Bulgarian",
			// "mejs.catalan": "Catalan",
			// "mejs.chinese": "Chinese",
			// "mejs.chinese-simplified": "Chinese (Simplified)",
			// "mejs.chinese-traditional": "Chinese (Traditional)",
			// "mejs.croatian": "Croatian",
			// "mejs.czech": "Czech",
			// "mejs.danish": "Danish",
			// "mejs.dutch": "Dutch",
			// "mejs.english": "English",
			// "mejs.estonian": "Estonian",
			// "mejs.filipino": "Filipino",
			// "mejs.finnish": "Finnish",
			// "mejs.french": "French",
			// "mejs.galician": "Galician",
			// "mejs.german": "German",
			// "mejs.greek": "Greek",
			// "mejs.haitian-creole": "Haitian Creole",
			// "mejs.hebrew": "Hebrew",
			// "mejs.hindi": "Hindi",
			// "mejs.hungarian": "Hungarian",
			// "mejs.icelandic": "Icelandic",
			// "mejs.indonesian": "Indonesian",
			// "mejs.irish": "Irish",
			// "mejs.italian": "Italian",
			// "mejs.japanese": "Japanese",
			// "mejs.korean": "Korean",
			// "mejs.latvian": "Latvian",
			// "mejs.lithuanian": "Lithuanian",
			// "mejs.macedonian": "Macedonian",
			// "mejs.malay": "Malay",
			// "mejs.maltese": "Maltese",
			// "mejs.norwegian": "Norwegian",
			// "mejs.persian": "Persian",
			// "mejs.polish": "Polish",
			// "mejs.portuguese": "Portuguese",
			// "mejs.romanian": "Romanian",
			// "mejs.russian": "Russian",
			// "mejs.serbian": "Serbian",
			// "mejs.slovak": "Slovak",
			// "mejs.slovenian": "Slovenian",
			// "mejs.spanish": "Spanish",
			// "mejs.swahili": "Swahili",
			// "mejs.swedish": "Swedish",
			// "mejs.tagalog": "Tagalog",
			// "mejs.thai": "Thai",
			// "mejs.turkish": "Turkish",
			// "mejs.ukrainian": "Ukrainian",
			// "mejs.vietnamese": "Vietnamese",
			// "mejs.welsh": "Welsh",
			// "mejs.yiddish": "Yiddish"
		};
	}
})(mejs.i18n);

==> mediaelement-3.2.1.tgz: package/src/js/languages/zh.js <==
'use strict';

/*!
 * This is a `i18n` language object.
 *
 * Chinese (Traditional)
 *
 * @author
 *   Jalios (Twitter: @Jalios)
 *   Sascha Greuel (Twitter: @SoftCreatR)
 *
 * @see core/i18n.js
 */
(function (exports) {
	if (exports.zh === undefined) {
		exports.zh = {
			"mejs.plural-form": 0,

			// renderers/flash.js
			// "mejs.install-flash": "You are using a browser that does not have Flash player enabled or installed. Please turn on your Flash player plugin or download the latest version from https://get.adobe.com/flashplayer/",

			// features/fullscreen.js
			"mejs.fullscreen": "全屏",

			// features/playpause.js
			"mejs.play": "播放",
			"mejs.pause": "暫停",

			// features/progress.js
			"mejs.time-slider": "時間滑動棒",
			"mejs.time-help-text": "使用左/右箭頭快進1秒，上/下箭頭快進10秒。",
			//"mejs.live-broadcast" : "Live Broadcast",

			// features/volume.js
			"mejs.volume-help-text": "使用上/下箭頭提高或降低音量。",
			"mejs.unmute": "取消靜音",
			"mejs.mute": "靜音",
			"mejs.volume-slider": "音量控制鍵",

			// core/player.js
			"mejs.video-player": "視頻播放器",
			"mejs.audio-player": "音頻播放器",

			// features/tracks.js
			"mejs.captions-subtitles": "字幕/標題",
			// "mejs.captions-chapters": "Chapters",
			"mejs.none": "沒有"
			// "mejs.afrikaans": "Afrikaans",
			// "mejs.albanian": "Albanian",
			// "mejs.arabic": "Arabic",
			// "mejs.belarusian": "Belarusian",
			// "mejs.bulgarian": "Bulgarian",
			// "mejs.catalan": "Catalan",
			// "mejs.chinese": "Chinese",
			// "mejs.chinese-simplified": "Chinese (Simplified)",
			// "mejs.chinese-traditional": "Chinese (Traditional)",
			// "mejs.croatian": "Croatian",
			// "mejs.czech": "Czech",
			// "mejs.danish": "Danish",
			// "mejs.dutch": "Dutch",
			// "mejs.english": "English",
			// "mejs.estonian": "Estonian",
			// "mejs.filipino": "Filipino",
			// "mejs.finnish": "Finnish",
			// "mejs.french": "French",
			// "mejs.galician": "Galician",
			// "mejs.german": "German",
			// "mejs.greek": "Greek",
			// "mejs.haitian-creole": "Haitian Creole",
			// "mejs.hebrew": "Hebrew",
			// "mejs.hindi": "Hindi",
			// "mejs.hungarian": "Hungarian",
			// "mejs.icelandic": "Icelandic",
			// "mejs.indonesian": "Indonesian",
			// "mejs.irish": "Irish",
			// "mejs.italian": "Italian",
			// "mejs.japanese": "Japanese",
			// "mejs.korean": "Korean",
			// "mejs.latvian": "Latvian",
			// "mejs.lithuanian": "Lithuanian",
			// "mejs.macedonian": "Macedonian",
			// "mejs.malay": "Malay",
			// "mejs.maltese": "Maltese",
			// "mejs.norwegian": "Norwegian",
			// "mejs.persian": "Persian",
			// "mejs.polish": "Polish",
			// "mejs.portuguese": "Portuguese",
			// "mejs.romanian": "Romanian",
			// "mejs.russian": "Russian",
			// "mejs.serbian": "Serbian",
			// "mejs.slovak": "Slovak",
			// "mejs.slovenian": "Slovenian",
			// "mejs.spanish": "Spanish",
			// "mejs.swahili": "Swahili",
			// "mejs.swedish": "Swedish",
			// "mejs.tagalog": "Tagalog",
			// "mejs.thai": "Thai",
			// "mejs.turkish": "Turkish",
			// "mejs.ukrainian": "Ukrainian",
			// "mejs.vietnamese": "Vietnamese",
			// "mejs.welsh": "Welsh",
			// "mejs.yiddish": "Yiddish"
		};
	}
})(mejs.i18n);
